==> zio-aws-cloudformation_2.12-5.17.129.3-sources.jar: zio/aws/cloudformation/model/RollbackStackResponse.scala <==
package zio.aws.cloudformation.model
import zio.aws.cloudformation.model.primitives.StackId
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class RollbackStackResponse(stackId: Option[StackId] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cloudformation.model.RollbackStackResponse = {
    import RollbackStackResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cloudformation.model.RollbackStackResponse
      .builder()
      .optionallyWith(
        stackId.map(value => StackId.unwrap(value): java.lang.String)
      )(_.stackId)
      .build()
  }
  def asReadOnly: zio.aws.cloudformation.model.RollbackStackResponse.ReadOnly =
    zio.aws.cloudformation.model.RollbackStackResponse.wrap(buildAwsValue())
}
object RollbackStackResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cloudformation.model.RollbackStackResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cloudformation.model.RollbackStackResponse =
      zio.aws.cloudformation.model
        .RollbackStackResponse(stackId.map(value => value))
    def stackId: Option[StackId]
    def getStackId: ZIO[Any, AwsError, StackId] =
      AwsError.unwrapOptionField("stackId", stackId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cloudformation.model.RollbackStackResponse
  ) extends zio.aws.cloudformation.model.RollbackStackResponse.ReadOnly {
    override val stackId: Option[StackId] = scala
      .Option(impl.stackId())
      .map(value => zio.aws.cloudformation.model.primitives.StackId(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.cloudformation.model.RollbackStackResponse
  ): zio.aws.cloudformation.model.RollbackStackResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-cloudformation_2.12-5.17.205.1-sources.jar: zio/aws/cloudformation/model/RollbackStackResponse.scala <==
package zio.aws.cloudformation.model
import zio.aws.cloudformation.model.primitives.StackId
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class RollbackStackResponse(
    stackId: Optional[StackId] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cloudformation.model.RollbackStackResponse = {
    import RollbackStackResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cloudformation.model.RollbackStackResponse
      .builder()
      .optionallyWith(
        stackId.map(value => StackId.unwrap(value): java.lang.String)
      )(_.stackId)
      .build()
  }
  def asReadOnly: zio.aws.cloudformation.model.RollbackStackResponse.ReadOnly =
    zio.aws.cloudformation.model.RollbackStackResponse.wrap(buildAwsValue())
}
object RollbackStackResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cloudformation.model.RollbackStackResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cloudformation.model.RollbackStackResponse =
      zio.aws.cloudformation.model
        .RollbackStackResponse(stackId.map(value => value))
    def stackId: Optional[StackId]
    def getStackId: ZIO[Any, AwsError, StackId] =
      AwsError.unwrapOptionField("stackId", stackId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cloudformation.model.RollbackStackResponse
  ) extends zio.aws.cloudformation.model.RollbackStackResponse.ReadOnly {
    override val stackId: Optional[StackId] = zio.aws.core.internal
      .optionalFromNullable(impl.stackId())
      .map(value => zio.aws.cloudformation.model.primitives.StackId(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.cloudformation.model.RollbackStackResponse
  ): zio.aws.cloudformation.model.RollbackStackResponse.ReadOnly = new Wrapper(
    impl
  )
}
